summaryrefslogtreecommitdiff
path: root/server.go
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2018-06-03 12:54:43 +0300
committerWolfy-J <[email protected]>2018-06-03 12:54:43 +0300
commit36ea77baa5a41de10bd604cd0e5b5b3cafaaeb64 (patch)
tree13ca8abd454a6668f490eec2e44b1520bd3953fe /server.go
parentb02611b7266589d888e054a1d2e4432ae370617d (diff)
service bus, http service, rpc bus, cli commands, new configs
Diffstat (limited to 'server.go')
-rw-r--r--server.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/server.go b/server.go
index d873da63..ef5bb413 100644
--- a/server.go
+++ b/server.go
@@ -8,13 +8,13 @@ import (
const (
// EventNewPool triggered when server creates new pool.
- EventNewPool = 3
+ EventNewPool = 60
// EventDestroyPool triggered when server destroys existed pool.
- EventDestroyPool = 4
+ EventDestroyPool = 61
)
-// Server manages pool creation and swapping.
+// Service manages pool creation and swapping.
type Server struct {
// observes pool events (can be attached to multiple pools at the same time)
observer func(event int, ctx interface{})
@@ -35,8 +35,8 @@ type Server struct {
pool Pool
}
-// NewRouter creates new router. Make sure to call configure before the usage.
-func NewRouter(cmd func() *exec.Cmd, factory Factory) *Server {
+// NewServer creates new router. Make sure to call configure before the usage.
+func NewServer(cmd func() *exec.Cmd, factory Factory) *Server {
return &Server{
cmd: cmd,
factory: factory,